@@ -12,6 +12,7 @@ definitions = {
         "TRANSFER_FUNDS_REJECT": "Transfer Funds Reject Transaction",
         "MARKET_ORDER": "Market Order Transaction",
         "MARKET_ORDER_REJECT": "Market Order Reject Transaction",
+        "FIXED_PRICE_ORDER": "Fixed Price Order Transaction",
         "LIMIT_ORDER": "Limit Order Transaction",
         "LIMIT_ORDER_REJECT": "Limit Order Reject Transaction",
         "STOP_ORDER": "Stop Order Transaction",
@@ -67,6 +68,10 @@ definitions = {
         "DELAYED_TRADE_CLOSE": "The Market Order was created to close a "
                                "trade marked for delayed closure",
     },
+    "FixedPriceOrderReason": {
+        "PLATFORM_ACCOUNT_MIGRATION": "The Fixed Price Order was created as "
+                                      "part of a platform account migration",
+    },
     "LimitOrderReason": {
         "CLIENT_ORDER": "The Limit Order was initiated at the request of a "
                         "client",
@@ -189,6 +194,52 @@ definitions = {
             "Filling the Order would result in the creation of a "
             "Stop Loss Order that would have been filled immediately, "
             "closing the new Trade at a loss.",
+        "STOP_LOSS_ON_FILL_PRICE_DISTANCE_MAXIMUM_EXCEEDED":
+            "Filling the Order would result in the creation of a Stop Loss "
+            "Order whose price would be zero or negative due to the "
+            "specified distance.",
+        "STOP_LOSS_ON_FILL_REQUIRED":
+            "Filling the Order would not result in the creation of Stop "
+            "Loss Order, however the Account’s configuration requires that "
+            "all Trades have a Stop Loss Order attached to them",
+        "STOP_LOSS_ON_FILL_GUARANTEED_REQUIRED":
+            "Filling the Order would not result in the creation of a "
+            "guaranteed Stop Loss Order, however the Account’s configuration "
+            "requires that all Trades have a guaranteed Stop Loss Order "
+            "attached to them",
+        "STOP_LOSS_ON_FILL_GUARANTEED_NOT_ALLOWED":
+            "Filling the Order would result in the creation of a guaranteed "
+            "Stop Loss Order, however the Account’s configuration does not "
+            "allow guaranteed Stop Loss Orders",
+        "STOP_LOSS_ON_FILL_GUARANTEED_MINIMUM_DISTANCE_NOT_MET":
+            "Filling the Order would result in the creation of a guaranteed "
+            "Stop Loss Order with a distance smaller than the configured "
+            "mininum distance.",
+        "STOP_LOSS_ON_FILL_GUARANTEED_LEVEL_RESTRICTION_EXCEEDED":
+            "Filling the Order would result in the creation of a guaranteed "
+            "Stop Loss Order with trigger price and number of units that "
+            "that violates the account’s guaranteed Stop Loss Order level "
+            "restriction",
+        "STOP_LOSS_ON_FILL_GUARANTEED_HEDGING_NOT_ALLOWED":
+            "Filling the Order would result in the creation of a guaranteed "
+            "Stop Loss Order for a hedged Trade, however the Account’s "
+            "configuration does not allow guaranteed Stop Loss Orders for "
+            "hedged Trades/Positions.",
+        "STOP_LOSS_ON_FILL_TIME_IN_FORCE_INVALID":
+            "Filling the Order would result in the creation of a Stop Loss "
+            "Order whose TimeInForce value is invalid. A likely cause would "
+            "be if the Account requires guaranteed stop loss orders and the "
+            "TimeInForce value were not GTC.",
+        "STOP_LOSS_ON_FILL_TRIGGER_CONDITION_INVALID":
+            "Filling the Order would result in the creation of a Stop Loss "
+            "Order whose TriggerCondition value is invalid. A likely cause "
+            "would be if the stop loss order is guaranteed and the "
+            "TimeInForce is not TRIGGER_DEFAULT or TRIGGER_BID for a long "
+            "trade, or not TRIGGER_DEFAULT or TRIGGER_ASK for a short trade.",
+        "TAKE_PROFIT_ON_FILL_PRICE_DISTANCE_MAXIMUM_EXCEEDED":
+            "Filling the Order would result in the creation of a Take Profit "
+            "Order whose price would be zero or negative due to the specified "
+            "distance.",
         "TRAILING_STOP_LOSS_ON_FILL_GTD_TIMESTAMP_IN_PAST":
             "Filling the Order would have resulted in the creation of a"
             "Trailing Stop Loss Order with a GTD time in the past.",
@@ -218,6 +269,15 @@ definitions = {
             "Filling the Order would have resulted in the "
             "Account’s maximum position size limit being exceeded "
             "for the Order’s instrument.",
+        "HEDGING_GSLO_VIOLATION":
+            "Filling the Order would result in the creation of a Trade, "
+            "however there already exists an opposing (hedged) Trade that "
+            "has a guaranteed Stop Loss Order attached to it. Guaranteed "
+            "Stop Loss Orders cannot be combined with hedged positions",
+        "ACCOUNT_POSITION_VALUE_LIMIT_EXCEEDED":
+            "Filling the order would cause the maximum position value "
+            "allowed for the account to be exceeded. The Order has been "
+            "cancelled as a result."
     },
     "MarketOrderMarginCloseoutReason": {
         "MARGIN_CHECK_VIOLATION": "Trade closures resulted from violating "
@@ -258,6 +318,10 @@ definitions = {
         "TRADE_IDENTIFIER_INCONSISTENCY": "The Trade ID and client Trade ID "
                                           "specified do not identify the "
                                           "same Trade",
+        "INSUFFICIENT_MARGIN":
+            "The Account had insufficient margin to perform the action "
+            "specified. One possible reason for this is due to the creation "
+            "or modification of a guaranteed StopLoss Order.",
         "INSTRUMENT_MISSING": "Order instrument has not been specified",
         "INSTRUMENT_UNKNOWN": "The instrument specified is unknown",
         "UNITS_MISSING": "Order units have not been not specified",
@@ -364,6 +428,66 @@ definitions = {
             "The Take Profit on fill specifies an invalid TriggerCondition",
         "STOP_LOSS_ORDER_ALREADY_EXISTS":
             "A Stop Loss Order for the specified Trade already exists",
+        "STOP_LOSS_ORDER_GUARANTEED_REQUIRED":
+            "An attempt was made to to create a non-guaranteed stop loss "
+            "order in an account that requires all stop loss orders to be "
+            "guaranteed.",
+        "STOP_LOSS_ORDER_GUARANTEED_PRICE_WITHIN_SPREAD":
+            "An attempt to create a guaranteed stop loss order with a price "
+            "that is within the current tradeable spread.",
+        "STOP_LOSS_ORDER_GUARANTEED_NOT_ALLOWED":
+            "An attempt was made to create a guaranteed Stop Loss Order, "
+            "however the Account’s configuration does not allow guaranteed "
+            "Stop Loss Orders.",
+        "STOP_LOSS_ORDER_GUARANTEED_HALTED_CREATE_VIOLATION":
+            "An attempt was made to create a guaranteed Stop Loss Order "
+            "when the market was halted.",
+        "STOP_LOSS_ORDER_GUARANTEED_HALTED_TIGHTEN_VIOLATION":
+            "An attempt was made to re-create a guaranteed Stop Loss Order"
+            "with a tighter fill price when the market was halted.",
+        "STOP_LOSS_ORDER_GUARANTEED_HEDGING_NOT_ALLOWED":
+            "An attempt was made to create a guaranteed Stop Loss Order on "
+            "a hedged Trade (ie there is an existing open Trade in the "
+            "opposing direction), however the Account’s configuration does "
+            "not allow guaranteed Stop Loss Orders for hedged "
+            "Trades/Positions.",
+        "STOP_LOSS_ORDER_GUARANTEED_MINIMUM_DISTANCE_NOT_MET":
+            "An attempt was made to create a guaranteed Stop Loss Order, "
+            "however the distance between the current price and the trigger "
+            "price does not meet the Account’s configured "
+            "minimumGuaranteedStopLossDistance.",
+        "STOP_LOSS_ORDER_NOT_CANCELABLE":
+            "An attempt was made to cancel a Stop Loss Order, however the "
+            "Account’s configuration requires every Trade have an associated "
+            "Stop Loss Order.",
+        "STOP_LOSS_ORDER_NOT_REPLACEABLE":
+            "An attempt was made to cancel and replace a Stop Loss Order, "
+            "however the Account’s configuration prevents the modification "
+            "of Stop Loss Orders.",
+        "STOP_LOSS_ORDER_GUARANTEED_LEVEL_RESTRICTION_EXCEEDED":
+            "An attempt was made to create a guaranteed Stop Loss Order, "
+            "however doing so would exceed the Account’s configured "
+            "guaranteed StopLoss Order level restriction volume.",
+        "STOP_LOSS_ORDER_PRICE_AND_DISTANCE_BOTH_SPECIFIED":
+            "The Stop Loss Order request contains both the price and "
+            "distance fields.",
+        "STOP_LOSS_ORDER_PRICE_AND_DISTANCE_BOTH_MISSING":
+            "The Stop Loss Order request contains neither the price nor "
+            "distance fields.",
+        "STOP_LOSS_ON_FILL_REQUIRED_FOR_PENDING_ORDER":
+            "An attempt to create a pending Order was made with no Stop "
+            "Loss Order on fill specified and the Account’s configuration "
+            "requires that every Trade have an associated Stop Loss Order.",
+        "STOP_LOSS_ON_FILL_GUARANTEED_NOT_ALLOWED":
+            "An attempt to create a pending Order was made with a Stop "
+            "Loss Order on fill that was explicitly configured to be "
+            "guaranteed, however the Account’s configuration does not allow "
+            "guaranteed Stop Loss Orders.",
+        "STOP_LOSS_ON_FILL_GUARANTEED_REQUIRED":
+            "An attempt to create a pending Order was made with a Stop Loss "
+            "Order on fill that was explicitly configured to be not "
+            "guaranteed, however the Account’s configuration requires "
+            "guaranteed Stop Loss Orders.",
         "STOP_LOSS_ON_FILL_PRICE_MISSING":
             "The Stop Loss on fill specified does not provide a price",
         "STOP_LOSS_ON_FILL_PRICE_INVALID":
@@ -371,6 +495,30 @@ definitions = {
         "STOP_LOSS_ON_FILL_PRICE_PRECISION_EXCEEDED":
             "The Stop Loss on fill specifies a price with more precision "
             "than is allowed by the Order’s instrument",
+        "STOP_LOSS_ON_FILL_GUARANTEED_MINIMUM_DISTANCE_NOT_MET":
+            "An attempt to create a pending Order was made with the "
+            "distance between the guaranteed Stop Loss Order on fill’s price "
+            "and the pending Order’s price is less than the Account’s "
+            "configured minimum guaranteed stop loss distance.",
+        "STOP_LOSS_ON_FILL_GUARANTEED_LEVEL_RESTRICTION_EXCEEDED":
+            "An attempt to create a pending Order was made with a guaranteed "
+            "Stop Loss Order on fill configured, and the Order’s units "
+            "exceed the Account’s configured guaranteed StopLoss Order level "
+            "restriction volume.",
+        "STOP_LOSS_ON_FILL_DISTANCE_INVALID":
+            "The Stop Loss on fill distance is invalid",
+        "STOP_LOSS_ON_FILL_PRICE_DISTANCE_MAXIMUM_EXCEEDED":
+            "The Stop Loss on fill price distance exceeds the maximum "
+            "allowed amount",
+        "STOP_LOSS_ON_FILL_DISTANCE_PRECISION_EXCEEDED":
+            "The Stop Loss on fill distance contains more precision than "
+            "is allowed by the instrument",
+        "STOP_LOSS_ON_FILL_PRICE_AND_DISTANCE_BOTH_SPECIFIED":
+            "The Stop Loss on fill contains both the price and distance "
+            "fields.",
+        "STOP_LOSS_ON_FILL_PRICE_AND_DISTANCE_BOTH_MISSING":
+            "The Stop Loss on fill contains neither the price nor distance "
+            "fields.",
         "STOP_LOSS_ON_FILL_TIME_IN_FORCE_MISSING":
             "The Stop Loss on fill specified does not provide a TimeInForce",
         "STOP_LOSS_ON_FILL_TIME_IN_FORCE_INVALID":
